@@ -10,29 +10,29 @@ class ModelPerfornance:
     def __init__(self, score_type="total_score"):
         self.score_type = score_type
 
-    # def calculate_prc_auc(self, recall_lst, precision_lst):
-    #     try:
-    #         pr_list = list(zip(precision_lst, recall_lst))
-    #         pr_list = [item for item in pr_list if -1 not in item]
-    #         precision_lst, recall_lst = list(zip(*pr_list))
-    #         auc_precision_recall = round(auc(recall_lst, precision_lst), 3)
-    #     except Exception:
-    #         precision_lst[-1] = -0.99999
-    #         precision_lst[-2] = -0.99999
-    #         pr_list = list(zip(precision_lst, recall_lst))
-    #         pr_list = [item for item in pr_list if -1 not in item]
-    #         precision_lst, recall_lst = list(zip(*pr_list))
-    #         auc_precision_recall = round(auc(recall_lst, precision_lst), 3)
-    #     return auc_precision_recall
-
     def calculate_prc_auc(self, recall_lst, precision_lst):
-        pr_list = list(zip(precision_lst, recall_lst))
-        pr_list = [item for item in pr_list if -1 not in item]
-        if len(pr_list):
+        try:
+            pr_list = list(zip(precision_lst, recall_lst))
+            pr_list = [item for item in pr_list if -1 not in item]
             precision_lst, recall_lst = list(zip(*pr_list))
             auc_precision_recall = round(auc(recall_lst, precision_lst), 3)
-            return [auc_precision_recall]
-        return [-1]
+        except Exception:
+            precision_lst[-1] = -0.99999
+            precision_lst[-2] = -0.99999
+            pr_list = list(zip(precision_lst, recall_lst))
+            pr_list = [item for item in pr_list if -1 not in item]
+            precision_lst, recall_lst = list(zip(*pr_list))
+            auc_precision_recall = round(auc(recall_lst, precision_lst), 3)
+        return [auc_precision_recall]
+
+    # def calculate_prc_auc(self, recall_lst, precision_lst):
+    #     pr_list = list(zip(precision_lst, recall_lst))
+    #     pr_list = [item for item in pr_list if -1 not in item]
+    #     if len(pr_list):
+    #         precision_lst, recall_lst = list(zip(*pr_list))
+    #         auc_precision_recall = round(auc(recall_lst, precision_lst), 3)
+    #         return [auc_precision_recall]
+    #     return [-1]
 
     def division(self, a, b):
         if sum(b):
