@@ -175,9 +175,9 @@ class GetConfArg:
         try:
             cnf_read = cnf(key)
             return cnf_read
-        except Exception as e:
+        except Exception:
             self.err_return_code = "0105"
-            self.err_reason = self.model_name + "-" + str(e.args[0])
+            self.err_reason = f"{self.model_name}-lack {key} env variables"
             return ""
     
     def read_train_conf_env(self):
@@ -273,15 +273,15 @@ class HitrustaiTrainTemple(GetConfArg):
         self.model_name = model_name
         self.dict_init_arg = None
         self.template_output_txt = '''
-INFO_MODEL_NAME: %s
-INFO_MODEL_ID: %s
-DATA_START_DATE: %s
-DATA_END_DATE: %s
-DATA_TOTAL_ROW: %s
-TRAINING_DATE: %s
-TRAINING_TIME: %s
-TRAINING_RETURN_CODE : %s
-TRAINING_REASON : %s
+INFO_MODEL_NAME="%s"
+INFO_MODEL_ID="%s"
+DATA_START_DATE="%s"
+DATA_END_DATE="%s"
+DATA_TOTAL_ROW="%s"
+TRAINING_DATE="%s"
+TRAINING_TIME="%s"
+TRAINING_RETURN_CODE="%s"
+TRAINING_REASON="%s"
         '''
 
     def err_template(self):
@@ -388,11 +388,12 @@ TRAINING_REASON : %s
 
     def train(self):
         try:
-            config = AutoConfig(search_path=os.getcwd() + "/env")
-            if config('ENV_METHOD') == "env":
-                self.read_train_conf_env()
-            else:
-                self.read_train_conf_apollo()
+            self.read_train_conf_env()
+            # config = AutoConfig(search_path=os.getcwd() + "/env")
+            # if config('ENV_METHOD') == "env":
+            #     self.read_train_conf_env()
+            # else:
+            #     self.read_train_conf_apollo()
             t1 = time.time()
             self.training_start_time_lst = datetime.datetime.now()
             self.dict_report = self.dict_model.train(chunksize=self.appollo_info["BATCH_SIZE"], true_lable_name=self.appollo_info["TRUE_LABEL_COLUMN"])
@@ -408,7 +409,10 @@ TRAINING_REASON : %s
                 self.dict_init_arg = self.input_arg_dict()
 
         except Exception as e:
-            self.err_reason = "FraudDetect-" + e.args[0]
+            if self.err_reason != "":
+                self.err_reason = self.err_reason
+            else:
+                self.err_reason = "FraudDetect-" + e.args[0]
             self.err_template()
 
     def insert_db(self, table_name, dict_add_column=None):
@@ -422,9 +426,12 @@ TRAINING_REASON : %s
                 table_name=table_name
             )
             tmts.insert_db(data=self.dict_init_arg, dict_add_column=dict_add_column)
-        except Exception as e:
+        except Exception:
             self.dict_init_arg["return_code"] = "0105"
-            self.dict_init_arg["reason"] = self.model_name + "-" + e.args[0]
+            if self.err_reason != "":
+                self.dict_init_arg["reason"] = self.err_reason
+            else:
+                self.dict_init_arg["reason"] = self.model_name + "-" + e.args[0]
 
     def output_txt(self, model_name="Fraud Detect", path='./data/lib/output.txt'):
         output_txt = self.template_output_txt % (
