@@ -12,11 +12,11 @@ def create_model_performance(table_name):
         Base_Model.metadata,
         Column("pk_id", Integer, primary_key=True,
                autoincrement=True, nullable=False),
-        Column("customer_id", VARCHAR(20)),
-        Column("training_id", VARCHAR(45)),
+        # Column("customer_id", VARCHAR(20)),
+        # Column("training_id", VARCHAR(45)),
         Column("model_id", VARCHAR(20)),
-        Column("profile_id", VARCHAR(20)),
-        Column("tag", VARCHAR(20)),
+        # Column("profile_id", VARCHAR(20)),
+        # Column("tag", VARCHAR(20)),
         Column("model_name", VARCHAR(100)),
         Column("training_start_time", TIMESTAMP()),
         Column("training_end_time", TIMESTAMP()),
